@@ -18,8 +18,8 @@ up your own URL patterns for these views instead.
 """
 
 
-from django.conf.urls.defaults import *
-from django.views.generic.simple import direct_to_template
+from django.conf.urls import *
+from django.views.generic.base import TemplateView
 
 from ...views import activate, register
 
@@ -30,8 +30,7 @@ urlpatterns = patterns('',
                            {'backend': 'registration.backends.simple.SimpleBackend'},
                            name='registration_register'),
                        url(r'^register/closed/$',
-                           direct_to_template,
-                           {'template': 'registration/registration_closed.html'},
+                           TemplateView.as_view(template_name='registration/registration_closed.html'),
                            name='registration_disallowed'),
                        (r'', include('django_couchdb_utils.registration.auth_urls')),
                        )
